import "whatwg-fetch";
export declare enum Method {
    GET = "GET",
    POST = "POST",
    PUT = "PUT",
    DELETE = "DELETE",
    PATCH = "PATCH",
}
export declare enum ContentType {
    FormUrlencoded = "application/x-www-form-urlencoded",
    JSON = "application/json",
    Multipart = "multipart/form-data",
}
export declare type bodyParserFunction = (requestBody: any) => any;
export declare type GetBody = (response: Response) => Promise<any>;
export interface IReduxAction {
    type: string;
    payload?: any;
}
export interface IResultObject {
    error?: Error;
    data?: any;
    status?: number;
    statusText?: string;
}
export declare const BodyParsers: {
    json(body: any): string;
    queryString(body: any): string;
};
export declare class HttpRequestError {
    name: string;
    message: any;
    response: any;
    jsonResponse: any;
    stack: any;
    status: number;
    constructor(message: string, status: number, response?: any);
}
export declare class HttpRequestBuilder {
    private url;
    private query;
    private middleware;
    private requestInit;
    setMethod(x: Method | string): this;
    getMethod(): any;
    setCredentials(x: RequestCredentials): this;
    getCredentials(): any;
    setContentType(x: ContentType | string): this;
    getContentType(): any;
    setAcceptType(x: string): this;
    getAcceptType(): any;
    setAuthorization(x: string): this;
    getAuthorization(): any;
    setUrl(x: string): this;
    getUrl(): string;
    setQuery(x: any): this;
    getQuery(): any;
    setBody(x: any): this;
    getBody(): any;
    applyBodyParserMiddleware(middleware: bodyParserFunction[] | bodyParserFunction): this;
    setRequestInit(x: RequestInit): this;
    getRequestInit(): any;
    setRequestExtraConfig(x: any): this;
    build(): Promise<Response>;
    toResult(getBody?: GetBody): Promise<IResultObject>;
    private execBodyParserMiddleware();
}
export declare function fetchSaga(request: (action: IReduxAction, store?: any) => Promise<any>, response: (response: Response) => IterableIterator<Promise<any> | IReduxAction>): (action: IReduxAction) => any;
